import sys
import math
import dumpParser


class VRMLGenerator:
    out = None
    
    def __init__(self,output):
        self.out = file(output,"w")
        
    def initialCode(self):
        self.out.write("""  
        #VRML V2.0 utf8

        PROTO KULICKA [
            field SFColor barva 1 1 1
            field SFVec3f pozice 0 0 0
        ]{
            Transform {
                translation	IS pozice
                children [
                    DEF	KULICKA Shape {
                        appearance Appearance {
                            material Material {
                                ambientIntensity 0.1
                                diffuseColor IS	barva
                                specularColor IS barva


                            }
                        }
                        geometry Sphere	{
                            radius 0.4 # kulicka rekneme v prumeru 20 cm
                        }
                    }
                ]
            }
        }
        PROTO KRYCHLE [
            field SFVec3f pozice 0 0 0
            field SFVec3f velikost 1 1 1
            field SFColor barva 1 1 1
            field SFFloat pruhlednost 0.5
            ]{
              Transform {
                 translation IS pozice
                     children [
                         Shape {
                             appearance Appearance {
                                 material Material {
                                     ambientIntensity 0.1
                                     diffuseColor IS barva
                                     specularColor IS barva
                                     transparency IS pruhlednost
                                     }
                             }
                             geometry Box {
                                size IS velikost
                             }
                          }
                      ]
              }
            }

        PROTO SIPKA [
            field SFVec3f stred 0 0 0
            field SFRotation orientace 0 0 1 0
            field SFFloat delka 1
            field SFColor barva 1 1 1
            ]{
                Transform {
                    translation IS stred
                    rotation IS orientace
                    children [
                        Shape {
                            appearance Appearance {
                                material Material {
                                    ambientIntensity 0.1
                                    diffuseColor IS barva
                                    specularColor IS barva
                                }
                            }
                            geometry Cylinder {
                                radius 0.05
                                height IS delka
                            }
                        }
                    ]
                }
            }

        # samotna scena k zobrazeni
        Group {
            children [
                KULICKA { barva 1 0.5 0 pozice 0 0 0 }
        """)


    def nodeOut(self,id):
        nodeLine = "KULICKA {\n"+\
            "  barva 1 1 0 "+\
            "  pozice "+`id[0]`+" "+`id[1]`+" "+`id[2]`+"\n}\n"
            
        self.out.write(nodeLine)

    def edgeOut(self,src,trg):
        xpos = src[0]
        ypos = src[1]
        zpos = src[2]
        
        xpos2= trg[0]
        ypos2= trg[1]
        zpos2= trg[2]
        
        xcenter = float(xpos+xpos2)/2
        ycenter = float(ypos+ypos2)/2
        zcenter = float(zpos+zpos2)/2
        
        dx = float(xpos-xpos2)
        dy = float(ypos-ypos2)
        dz = float(zpos-zpos2)
      
        planexzlength = math.sqrt((dx*dx)+(dz*dz))
        if (dy==0):
            angle = math.pi/2
        else:
            angle = math.atan(planexzlength/dy)
      
        
        length = math.sqrt(dx*dx+dy*dy+dz*dz)
        
        nodeLine = "SIPKA {\n"+\
            "  stred  "+`xcenter`+" "+`ycenter`+" "+`zcenter`+\
          "\n  orientace "+`dz`+" 0 "+`-dx`+" " + `angle` +\
          "\n  delka " + `length`+ "}\n"
             #`zangle`+\
        self.out.write(nodeLine)

        
    def terminalCode(self):
        self.out.write("\n]}")

generators = []
generators.append(VRMLGenerator(sys.argv[2]))

dp = dumpParser.DumpParser(generators)
input = file(sys.argv[1])

dp.parse(input)


